Module encrypted

Module encrypted 

Encrypted MTProto 2.0 session (post auth-key).

Once you have a Finished from crate::authentication, construct an EncryptedSession and use it to serialize/deserialize all subsequent messages.

Structs

DecryptedMessage
The inner payload extracted from a successfully decrypted server frame.
EncryptedSession
MTProto 2.0 encrypted session state.

Enums

DecryptError
Errors that can occur when decrypting a server message.