pub struct MessageId(pub u64);Expand description
A 64-bit MTProto message identifier.
Per the spec: the lower 32 bits are derived from the current Unix time; the upper 32 bits are a monotonically increasing counter within the second. The least significant two bits must be zero for client messages.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Ord for MessageId
impl Ord for MessageId
Sourceimpl PartialOrd for MessageId
impl PartialOrd for MessageId
impl Copy for MessageId
impl Eq for MessageId
impl StructuralPartialEq for MessageId